/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.editor.handler;


import java.io.File;
import java.io.IOException;

import org.biojava.bio.chromatogram.UnsupportedChromatogramFormatException;
import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.swt.widgets.FileDialog;
import org.eclipse.ui.IEditorPart;

import eu.etaxonomy.taxeditor.editor.molecular.AlignmentEditor;
import eu.etaxonomy.taxeditor.model.AbstractUtility;
import eu.etaxonomy.taxeditor.model.MessagingUtils;



/**
 * Handler that loads an additional read into the contig alignment displayed by an instance of {@link AlignmentEditor}.
 * 
 * @author Ben Stöver
 * @author pplitzner
 */
public class LoadPherogramHandler extends AbstractHandler {
	//TODO Change so that also URIs which do not point to files can be specified.
	
	/* (non-Javadoc)
     * @see org.eclipse.core.commands.IHandler#execute(org.eclipse.core.commands.ExecutionEvent)
     */
    @Override
    public Object execute(ExecutionEvent event) throws ExecutionException {
        IEditorPart activeEditor = AbstractUtility.getActiveEditor();
        if (activeEditor instanceof AlignmentEditor) {
            AlignmentEditor alignmentEditor = (AlignmentEditor)activeEditor;
            
            FileDialog fileDialog = new FileDialog(alignmentEditor.getSite().getShell());
            fileDialog.setText("Import pherogram into contig alignment");
            fileDialog.setFilterNames(new String[]{"All supported formats", "AB1 pherogram files", "SCF pherogram files", "All files"});
            fileDialog.setFilterExtensions(new String[]{"*.ab1;*.scf", "*.ab1", "*.scf", "*.*"});
            
            String path = fileDialog.open();
            if (path != null) {
            	try {
            		alignmentEditor.addRead(new File(path).toURI(), false);
            	}
            	catch (UnsupportedChromatogramFormatException e) {
                    MessagingUtils.errorDialog("Unsupported format", this, "The format of the pherogram file \"" + path + 
                    		"\" is not supported. (Only AB1 and SCF are supported.)", "eu.etaxonomy.taxeditor.editor", e, false);  //TODO set pluginID
            	}
            	catch (IOException e) {
                    MessagingUtils.errorDialog("Unsupported format", this, 
                    		"An IO error occurred while trying to read the file \"" + path + "\".", 
                    		"/eu.etaxonomy.taxeditor.editor", e, false);  //TODO set pluginID
            	}
            }
        }
        return null;
    }
}
