package eu.etaxonomy.taxeditor.editor.handler;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.handlers.HandlerUtil;

import eu.etaxonomy.cdm.model.taxon.Classification;
import eu.etaxonomy.cdm.model.taxon.TaxonNode;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.editor.view.checklist.ChecklistEditorInput;
import eu.etaxonomy.taxeditor.model.AbstractUtility;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.preference.IPreferenceKeys;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;

public class OpenChecklistEditorHandler extends AbstractHandler {

    private static final Logger logger = Logger.getLogger(OpenChecklistEditorHandler.class);

    /*
     * (non-Javadoc)
     *
     * @see
     * org.eclipse.core.commands.IHandler#execute(org.eclipse.core.commands.
     * ExecutionEvent)
     */
    @Override
    public Object execute(ExecutionEvent event) throws ExecutionException {
        boolean isChecklistEditorActivated = PreferencesUtil.getPreferenceStore().getBoolean(
                IPreferenceKeys.DISTRIBUTION_AREA_PREFRENCES_ACTIVE);
        if (isChecklistEditorActivated) {
            ISelection currentSelection = HandlerUtil.getCurrentSelection(event);
            if (currentSelection instanceof IStructuredSelection) {
                Object selectedElement = ((IStructuredSelection) currentSelection).getFirstElement();
                if (selectedElement instanceof Classification) {
                    ChecklistEditorInput input = new ChecklistEditorInput(((Classification) selectedElement));
                    try {
                        EditorUtil.open(input);
                    } catch (PartInitException e) {
                    	MessagingUtils.error(OpenChecklistEditorHandler.class, "Could not open ChecklistView", e);
                    } catch (NullPointerException npe) {
                    	MessagingUtils.messageDialog("Failed to open Editor", OpenChecklistEditorHandler.class,
                                "Could not open ChecklistView. The hierarchy is corrupted!", npe);
                    }
                } else if (selectedElement instanceof TaxonNode) {
                    ChecklistEditorInput input = new ChecklistEditorInput(((TaxonNode) selectedElement));
                    try {
                        EditorUtil.open(input);
                    } catch (PartInitException e) {
                    	MessagingUtils.error(OpenChecklistEditorHandler.class, "Could not open ChecklistView", e);
                    } catch (NullPointerException npe) {
                    	MessagingUtils.messageDialog("Failed to open Editor", OpenChecklistEditorHandler.class,
                                "Could not open ChecklistView. The hierarchy is corrupted!", npe);
                    }
                }
            }
        }
        return null;
    }
}
