/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.handler.alignmenteditor;


import java.util.Map;

import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.commands.ICommandService;
import org.eclipse.ui.commands.IElementUpdater;
import org.eclipse.ui.menus.UIElement;

import eu.etaxonomy.taxeditor.editor.handler.HandlerTools;
import eu.etaxonomy.taxeditor.editor.molecular.AlignmentEditor;
import eu.etaxonomy.taxeditor.model.AbstractUtility;



/**
 * Switches an {@link AlignmentEditor} between insertion and overwrite mode.
 *
 * @author Ben Stöver
 * @date 04.12.2014
 */
public class ToggleInsertOverwriteHandler extends AbstractAlignmentEditorHandler implements IElementUpdater {
	public static final String COMMAND_ID =
			"eu.etaxonomy.taxeditor.editor.molecular.AlignmentEditor.toggleInsertOverwrite";


    private final ImageDescriptor INSERT_DESCRIPTOR = HandlerTools.createImageDescriptor("insert-16x16.png");
    private final ImageDescriptor OVERWRITE_DESCRIPTOR = HandlerTools.createImageDescriptor("overwrite-16x16.png");


    @Override
    public void doExecute(ExecutionEvent event, AlignmentEditor editor) throws ExecutionException {
        editor.toggleInsertOverwrite();
    }


	@Override
	public void updateElement(UIElement element, @SuppressWarnings("rawtypes") Map parameters) {
        IEditorPart activeEditor = AbstractUtility.getActiveEditor();
		if (activeEditor instanceof AlignmentEditor) {
			if (((AlignmentEditor)activeEditor).isInsertMode()) {
			    element.setIcon(INSERT_DESCRIPTOR);
				element.setText("INS");
				element.setTooltip("Click to switch to overwrite mode");
			}
			else {
                element.setIcon(OVERWRITE_DESCRIPTOR);
				element.setText("OVR");
				element.setTooltip("Click to switch to insertion mode");
			}
            ((ICommandService)PlatformUI.getWorkbench().getService(ICommandService.class)).refreshElements(
                    ToggleLeftRightInsertionHandler.COMMAND_ID, null);
		}
	}
}
