/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.editor.molecular;


import info.bioinfweb.libralign.pherogram.PherogramFormats.QualityOutputType;
import info.bioinfweb.libralign.pherogram.model.PherogramComponentModel;
import info.bioinfweb.libralign.pherogram.view.PherogramView;
import info.bioinfweb.tic.SWTComponentFactory;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.part.ViewPart;



/**
 * Component that allows to view a pherogram without the distortion due to aligning it to a sequence as in
 * {@link AlignmentEditor}.
 *
 * @author Ben Stöver
 * @date Nov 20, 2014
 */
public class PherogramViewPart extends ViewPart {
    public static final String ID = "eu.etaxonomy.taxeditor.editor.molecular.PherogramView";

    private PherogramView pherogramView = null;


    public static PherogramViewPart createView(PherogramComponentModel model) throws PartInitException {
        PherogramViewPart view = (PherogramViewPart)PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage().showView(ID);
        view.getPherogramView().getTraceCurveView().setModel(model);
        view.getPherogramView().assignSize();
        return view;
    }


	public PherogramView getPherogramView() {
		if (pherogramView == null) {
			pherogramView = new PherogramView();
			pherogramView.getTraceCurveView().getFormats().setShowProbabilityValues(true);
			pherogramView.getTraceCurveView().setHorizontalScale(1);
			pherogramView.getTraceCurveView().setVerticalScale(100);
			pherogramView.getTraceCurveView().getFormats().setQualityOutputType(QualityOutputType.NONE);  //TODO Make this user defined
			pherogramView.getTraceCurveView().getFormats().setShowProbabilityValues(false);
		}
		return pherogramView;
	}


	@Override
	public void createPartControl(Composite parent) {
		SWTComponentFactory.getInstance().getSWTComponent(getPherogramView(), parent, SWT.NONE);
		getPherogramView().assignSize();
	}


	@Override
	public void setFocus() {}  // nothing to do
}
