/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.name.container;

import java.util.HashSet;
import java.util.Set;

import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.editor.name.TaxonNameEditor;

/**
 * <p>MisappliedGroup class.</p>
 *
 * @author p.ciardelli
 * @created 13.01.2009
 * @version 1.0
 */
public class MisappliedGroup extends AbstractGroup{

	/**
	 * <p>Constructor for MisappliedGroup.</p>
	 *
	 * @param editor a {@link eu.etaxonomy.taxeditor.editor.name.TaxonNameEditor} object.
	 */
	public MisappliedGroup(TaxonNameEditor editor) {
		super(editor);
		
		createContent();
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.editor.name.AbstractGroup#createContents()
	 */
	@Override
	protected void createContainers() {
		for(Taxon misapplication : getEditor().getTaxon().getMisappliedNames()){
			MisapplicationContainer container = new MisapplicationContainer(this, misapplication);
			this.add(container);
			container.createContent();
		}
	}
	
	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.editor.name.container.AbstractGroup#redraw()
	 */
	@Override
	public void redraw() {
		if(redrawNeeded()){
			super.redraw();
		}
	}

	/**
	 * @return
	 */
	private boolean redrawNeeded() {
		Set<Taxon> misapplications = getEditor().getTaxon().getMisappliedNames();
				
		Set<Taxon> presentMisapplication = new HashSet<Taxon>(); 
		
		for (AbstractGroupedContainer<Taxon> container  : getGroupedContainers()){
			presentMisapplication.add(container.getData());
		}
		return ! (presentMisapplication.containsAll(misapplications) && misapplications.containsAll(presentMisapplication));
	}
}
