package eu.etaxonomy.taxeditor.editor.view.checklist.edit;

import java.util.List;

import org.apache.log4j.Logger;
import org.eclipse.jface.viewers.ArrayContentProvider;
import org.eclipse.jface.viewers.CellEditor;
import org.eclipse.jface.viewers.ComboBoxViewerCellEditor;
import org.eclipse.jface.viewers.EditingSupport;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;

import eu.etaxonomy.cdm.model.name.Rank;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.editor.view.checklist.ChecklistEditor;
import eu.etaxonomy.taxeditor.store.CdmStore;

public final class RankEditingSupport extends EditingSupport{

    private ComboBoxViewerCellEditor cellEditor = null;
    private final TableViewer viewer;
    private final ChecklistEditor editor;


    private static final Logger logger = Logger.getLogger(RankEditingSupport.class);

    public RankEditingSupport(TableViewer viewer, ChecklistEditor checklistEditor) {
        super(viewer);
        this.viewer = viewer;
        editor = checklistEditor;
        cellEditor = new ComboBoxViewerCellEditor((Composite) viewer.getControl(), SWT.READ_ONLY);
        cellEditor.setLabelProvider(new LabelProvider());
        cellEditor.setContentProvider(new ArrayContentProvider());
        //TODO set input
        List<Rank> input = CdmStore.getTermManager().getPreferredTerms(Rank.class);
        cellEditor.setInput(input);
    }

    @Override
    protected CellEditor getCellEditor(Object element) {
        return cellEditor;
    }

    @Override
    protected boolean canEdit(Object element) {
        return true;
    }

    @Override
    protected Object getValue(Object element) {
        if (element instanceof Taxon) {
            Taxon taxon = (Taxon)element;
            Rank rank = (taxon.getName().getRank() != null)?taxon.getName().getRank() : null;
            return rank;
        }
        return null;
    }

    @Override
    protected void setValue(Object element, Object value) {
        if (element instanceof Taxon && value instanceof Rank) {
            Taxon taxon = (Taxon)element;
            Rank rank = (Rank) value;
            taxon.getName().setRank(rank);
            viewer.update(element, null);
            viewer.refresh();
            editor.setDirty(true);
            editor.changed(element);
        }
    }

}