// $Id$
/**
* Copyright (C) 2013 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.editor.view.dataimport.transientServices;

import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.UUID;

import org.hibernate.LockOptions;
import org.hibernate.Session;
import org.hibernate.criterion.Criterion;
import org.hibernate.envers.query.criteria.AuditCriterion;

import eu.etaxonomy.cdm.api.service.DeleteResult;
import eu.etaxonomy.cdm.api.service.DistributionTree;
import eu.etaxonomy.cdm.api.service.IDescriptionService;
import eu.etaxonomy.cdm.api.service.UpdateResult;
import eu.etaxonomy.cdm.api.service.config.DeleteConfiguratorBase;
import eu.etaxonomy.cdm.api.service.config.IIdentifiableEntityServiceConfigurator;
import eu.etaxonomy.cdm.api.service.dto.FindByIdentifierDTO;
import eu.etaxonomy.cdm.api.service.pager.Pager;
import eu.etaxonomy.cdm.common.monitor.IProgressMonitor;
import eu.etaxonomy.cdm.model.common.Annotation;
import eu.etaxonomy.cdm.model.common.DefinedTerm;
import eu.etaxonomy.cdm.model.common.ISourceable;
import eu.etaxonomy.cdm.model.common.IdentifiableSource;
import eu.etaxonomy.cdm.model.common.LSID;
import eu.etaxonomy.cdm.model.common.Language;
import eu.etaxonomy.cdm.model.common.Marker;
import eu.etaxonomy.cdm.model.common.MarkerType;
import eu.etaxonomy.cdm.model.common.TermVocabulary;
import eu.etaxonomy.cdm.model.description.DescriptionBase;
import eu.etaxonomy.cdm.model.description.DescriptionElementBase;
import eu.etaxonomy.cdm.model.description.Feature;
import eu.etaxonomy.cdm.model.description.FeatureTree;
import eu.etaxonomy.cdm.model.description.PresenceAbsenceTerm;
import eu.etaxonomy.cdm.model.description.TaxonDescription;
import eu.etaxonomy.cdm.model.description.TaxonNameDescription;
import eu.etaxonomy.cdm.model.location.NamedArea;
import eu.etaxonomy.cdm.model.location.NamedAreaLevel;
import eu.etaxonomy.cdm.model.media.Media;
import eu.etaxonomy.cdm.model.media.Rights;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.view.AuditEvent;
import eu.etaxonomy.cdm.model.view.AuditEventRecord;
import eu.etaxonomy.cdm.persistence.dao.common.AuditEventSort;
import eu.etaxonomy.cdm.persistence.dto.TermDto;
import eu.etaxonomy.cdm.persistence.dto.UuidAndTitleCache;
import eu.etaxonomy.cdm.persistence.query.Grouping;
import eu.etaxonomy.cdm.persistence.query.MatchMode;
import eu.etaxonomy.cdm.persistence.query.OrderHint;
import eu.etaxonomy.cdm.strategy.cache.common.IIdentifiableEntityCacheStrategy;
import eu.etaxonomy.cdm.strategy.match.IMatchStrategy;
import eu.etaxonomy.cdm.strategy.merge.IMergeStrategy;

/**
 * @author pplitzner
 * @date 27.09.2013
 *
 */
public class TransientDescriptionService implements IDescriptionService {

    private final IDescriptionService defaultService;

    /**
     * @param defaultDescriptionService
     */
    public TransientDescriptionService(IDescriptionService defaultDescriptionService) {
        this.defaultService = defaultDescriptionService;
    }

    /**
     * @param t
     * @param pageSize
     * @param pageNumber
     * @param sort
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IVersionableService#pageAuditEvents(eu.etaxonomy.cdm.model.common.VersionableEntity, java.lang.Integer, java.lang.Integer, eu.etaxonomy.cdm.persistence.dao.common.AuditEventSort, java.util.List)
     */
    @Override
    public Pager<AuditEventRecord<DescriptionBase>> pageAuditEvents(DescriptionBase t, Integer pageSize, Integer pageNumber, AuditEventSort sort, List<String> propertyPaths) {
        return defaultService.pageAuditEvents(t, pageSize, pageNumber, sort, propertyPaths);
    }

    /**
     * @param annotatedObj
     * @param status
     * @param pageSize
     * @param pageNumber
     * @param orderHints
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IAnnotatableService#getAnnotations(eu.etaxonomy.cdm.model.common.AnnotatableEntity, eu.etaxonomy.cdm.model.common.MarkerType, java.lang.Integer, java.lang.Integer, java.util.List, java.util.List)
     */
    @Override
    public Pager<Annotation> getAnnotations(DescriptionBase annotatedObj, MarkerType status, Integer pageSize, Integer pageNumber, List<OrderHint> orderHints, List<String> propertyPaths) {
        return defaultService.getAnnotations(annotatedObj, status, pageSize, pageNumber, orderHints, propertyPaths);
    }

    /**
     *
     * @see eu.etaxonomy.cdm.api.service.IService#clear()
     */
    @Override
    public void clear() {
        defaultService.clear();
    }

    /**
     * @param t
     * @param lockMode
     * @see eu.etaxonomy.cdm.api.service.IService#lock(eu.etaxonomy.cdm.model.common.ICdmBase, org.hibernate.LockMode)
     */
    @Override
    public void lock(DescriptionBase t, LockOptions lockOptions) {
        defaultService.lock(t, lockOptions);
    }

    /**
     * @param t
     * @param lockMode
     * @param propertyPaths
     * @see eu.etaxonomy.cdm.api.service.IService#refresh(eu.etaxonomy.cdm.model.common.ICdmBase, org.hibernate.LockMode, java.util.List)
     */
    @Override
    public void refresh(DescriptionBase t, LockOptions lockOptions, List<String> propertyPaths) {
        defaultService.refresh(t, lockOptions, propertyPaths);
    }

    /**
     *
     * @see eu.etaxonomy.cdm.api.service.IIdentifiableEntityService#updateTitleCache()
     */
    @Override
    public void updateTitleCache() {
        defaultService.updateTitleCache();
    }

    /**
     * @param t
     * @return
     * @see eu.etaxonomy.cdm.api.service.IVersionableService#getNextAuditEvent(eu.etaxonomy.cdm.model.common.VersionableEntity)
     */
    @Override
    public AuditEventRecord<DescriptionBase> getNextAuditEvent(DescriptionBase t) {
        return defaultService.getNextAuditEvent(t);
    }

    /**
     * @return
     * @deprecated
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#getDefaultFeatureVocabulary()
     */
    @Deprecated
    @Override
    public TermVocabulary<Feature> getDefaultFeatureVocabulary() {
        return defaultService.getDefaultFeatureVocabulary();
    }

    /**
     * @param annotatableEntity
     * @param technical
     * @param pageSize
     * @param pageNumber
     * @param orderHints
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IAnnotatableService#getMarkers(eu.etaxonomy.cdm.model.common.AnnotatableEntity, java.lang.Boolean, java.lang.Integer, java.lang.Integer, java.util.List, java.util.List)
     */
    @Override
    public Pager<Marker> getMarkers(DescriptionBase annotatableEntity, Boolean technical, Integer pageSize, Integer pageNumber, List<OrderHint> orderHints, List<String> propertyPaths) {
        return defaultService.getMarkers(annotatableEntity, technical, pageSize, pageNumber, orderHints, propertyPaths);
    }

    /**
     * @param uuid
     * @return
     * @deprecated
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#getFeatureVocabulary(java.util.UUID)
     */
    @Deprecated
    @Override
    public TermVocabulary<Feature> getFeatureVocabulary(UUID uuid) {
        return defaultService.getFeatureVocabulary(uuid);
    }

    /**
     * @param clazz
     * @param stepSize
     * @param cacheStrategy
     * @param monitor
     * @see eu.etaxonomy.cdm.api.service.IIdentifiableEntityService#updateTitleCache(java.lang.Class, java.lang.Integer, eu.etaxonomy.cdm.strategy.cache.common.IIdentifiableEntityCacheStrategy, eu.etaxonomy.cdm.common.monitor.IProgressMonitor)
     */
    @Override
    public void updateTitleCache(Class<? extends DescriptionBase> clazz, Integer stepSize, IIdentifiableEntityCacheStrategy<DescriptionBase> cacheStrategy, IProgressMonitor monitor) {
        defaultService.updateTitleCache(clazz, stepSize, cacheStrategy, monitor);
    }

    /**
     * @param t
     * @return
     * @see eu.etaxonomy.cdm.api.service.IVersionableService#getPreviousAuditEvent(eu.etaxonomy.cdm.model.common.VersionableEntity)
     */
    @Override
    public AuditEventRecord<DescriptionBase> getPreviousAuditEvent(DescriptionBase t) {
        return defaultService.getPreviousAuditEvent(t);
    }

    /**
     * @param uuid
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#getDescriptionElementByUuid(java.util.UUID)
     */
    @Override
    public DescriptionElementBase getDescriptionElementByUuid(UUID uuid) {
        return defaultService.getDescriptionElementByUuid(uuid);
    }

    /**
     * @param clazz
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#count(java.lang.Class)
     */
    @Override
    public int count(Class<? extends DescriptionBase> clazz) {
        return defaultService.count(clazz);
    }

    /**
     * @param uuid
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#loadDescriptionElement(java.util.UUID, java.util.List)
     */
    @Override
    public DescriptionElementBase loadDescriptionElement(UUID uuid, List<String> propertyPaths) {
        return defaultService.loadDescriptionElement(uuid, propertyPaths);
    }

    /**
     * @param clazz
     * @param from
     * @param to
     * @param criteria
     * @param pageSize
     * @param pageValue
     * @param sort
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IVersionableService#pageAuditEvents(java.lang.Class, eu.etaxonomy.cdm.model.view.AuditEvent, eu.etaxonomy.cdm.model.view.AuditEvent, java.util.List, java.lang.Integer, java.lang.Integer, eu.etaxonomy.cdm.persistence.dao.common.AuditEventSort, java.util.List)
     */
    @Override
    public Pager<AuditEventRecord<DescriptionBase>> pageAuditEvents(Class<? extends DescriptionBase> clazz, AuditEvent from, AuditEvent to, List<AuditCriterion> criteria, Integer pageSize, Integer pageValue, AuditEventSort sort, List<String> propertyPaths) {
        return defaultService.pageAuditEvents(clazz, from, to, criteria, pageSize, pageValue, sort, propertyPaths);
    }

    /**
     * @param lsid
     * @return
     * @see eu.etaxonomy.cdm.api.service.IIdentifiableEntityService#find(eu.etaxonomy.cdm.model.common.LSID)
     */
    @Override
    public DescriptionBase find(LSID lsid) {
        return defaultService.find(lsid);
    }

    /**
     * @param persistentObject
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#delete(eu.etaxonomy.cdm.model.common.ICdmBase)
     */
    @Override
    public DeleteResult delete(DescriptionBase persistentObject) {
        return defaultService.delete(persistentObject);
    }

    /**
     * @param clazz
     * @param technical
     * @param pageSize
     * @param pageNumber
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IAnnotatableService#groupMarkers(java.lang.Class, java.lang.Boolean, java.lang.Integer, java.lang.Integer, java.util.List)
     */
    @Override
    public List<Object[]> groupMarkers(Class<? extends DescriptionBase> clazz, Boolean technical, Integer pageSize, Integer pageNumber, List<String> propertyPaths) {
        return defaultService.groupMarkers(clazz, technical, pageSize, pageNumber, propertyPaths);
    }

    /**
     * @param uuid
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#exists(java.util.UUID)
     */
    @Override
    public boolean exists(UUID uuid) {
        return defaultService.exists(uuid);
    }

    /**
     * @param x
     * @param y
     * @return
     * @see eu.etaxonomy.cdm.api.service.IIdentifiableEntityService#replace(eu.etaxonomy.cdm.model.common.IdentifiableEntity, eu.etaxonomy.cdm.model.common.IdentifiableEntity)
     */
    @Override
    public DescriptionBase replace(DescriptionBase x, DescriptionBase y) {
        return defaultService.replace(x, y);
    }

    /**
     * @param descriptionElement
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#saveDescriptionElement(eu.etaxonomy.cdm.model.description.DescriptionElementBase)
     */
    @Override
    public UUID saveDescriptionElement(DescriptionElementBase descriptionElement) {
        return null;
    }

    /**
     * @param uuidSet
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#find(java.util.Set)
     */
    @Override
    public List<DescriptionBase> find(Set<UUID> uuidSet) {
        return defaultService.find(uuidSet);
    }

    /**
     * @param descriptionElements
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#saveDescriptionElement(java.util.Collection)
     */
    @Override
    public Map<UUID, DescriptionElementBase> saveDescriptionElement(Collection<DescriptionElementBase> descriptionElements) {
        return null;
    }

    /**
     * @param t
     * @param pageSize
     * @param pageNumber
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IIdentifiableEntityService#getSources(eu.etaxonomy.cdm.model.common.IdentifiableEntity, java.lang.Integer, java.lang.Integer, java.util.List)
     */
    @Override
    public Pager<IdentifiableSource> getSources(DescriptionBase t, Integer pageSize, Integer pageNumber, List<String> propertyPaths) {
        return defaultService.getSources(t, pageSize, pageNumber, propertyPaths);
    }

    /**
     * @param descriptionElement
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#deleteDescriptionElement(eu.etaxonomy.cdm.model.description.DescriptionElementBase)
     */
    @Override
    public UUID deleteDescriptionElement(DescriptionElementBase descriptionElement) {
        return defaultService.deleteDescriptionElement(descriptionElement);
    }

    /**
     * @param uuid
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#find(java.util.UUID)
     */
    @Override
    public DescriptionBase find(UUID uuid) {
        return defaultService.find(uuid);
    }

    /**
     * @param type
     * @param hasMedia
     * @param hasText
     * @param feature
     * @param pageSize
     * @param pageNumber
     * @param orderHints
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#page(java.lang.Class, java.lang.Boolean, java.lang.Boolean, java.util.Set, java.lang.Integer, java.lang.Integer, java.util.List, java.util.List)
     */
    @Override
    public Pager<DescriptionBase> page(Class<? extends DescriptionBase> type, Boolean hasMedia, Boolean hasText, Set<Feature> feature, Integer pageSize, Integer pageNumber, List<OrderHint> orderHints, List<String> propertyPaths) {
        return defaultService.page(type, hasMedia, hasText, feature, pageSize, pageNumber, orderHints, propertyPaths);
    }

    /**
     * @param id
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#find(int)
     */
    @Override
    public DescriptionBase find(int id) {
        return defaultService.find(id);
    }

    /**
     * @param t
     * @param pageSize
     * @param pageNumber
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IIdentifiableEntityService#getRights(eu.etaxonomy.cdm.model.common.IdentifiableEntity, java.lang.Integer, java.lang.Integer, java.util.List)
     */
    @Override
    public Pager<Rights> getRights(DescriptionBase t, Integer pageSize, Integer pageNumber, List<String> propertyPaths) {
        return defaultService.getRights(t, pageSize, pageNumber, propertyPaths);
    }

    /**
     * @param clazz
     * @param technical
     * @return
     * @see eu.etaxonomy.cdm.api.service.IAnnotatableService#countMarkers(java.lang.Class, java.lang.Boolean)
     */
    @Override
    public int countMarkers(Class<? extends DescriptionBase> clazz, Boolean technical) {
        return defaultService.countMarkers(clazz, technical);
    }

    /**
     * @param idSet
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#findById(java.util.Set)
     */
    @Override
    public List<DescriptionBase> findById(Set<Integer> idSet) {
        return defaultService.findById(idSet);
    }

    /**
     * @param clazz
     * @param idInSource
     * @param idNamespace
     * @return
     * @see eu.etaxonomy.cdm.api.service.IIdentifiableEntityService#getSourcedObjectByIdInSource(java.lang.Class, java.lang.String, java.lang.String)
     */
    @Override
    public ISourceable getSourcedObjectByIdInSource(Class clazz, String idInSource, String idNamespace) {
        return defaultService.getSourcedObjectByIdInSource(clazz, idInSource, idNamespace);
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#getSession()
     */
    @Override
    public Session getSession() {
        return defaultService.getSession();
    }

    /**
     * @return
     * @see eu.etaxonomy.cdm.api.service.IIdentifiableEntityService#getUuidAndTitleCache()
     */
    @Override
    public List<UuidAndTitleCache<DescriptionBase>> getUuidAndTitleCache() {
        return defaultService.getUuidAndTitleCache();
    }

    /**
     * @param clazz
     * @param limit
     * @param start
     * @param groups
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#group(java.lang.Class, java.lang.Integer, java.lang.Integer, java.util.List, java.util.List)
     */
    @Override
    public List<Object[]> group(Class<? extends DescriptionBase> clazz, Integer limit, Integer start, List<Grouping> groups, List<String> propertyPaths) {
        return defaultService.group(clazz, limit, start, groups, propertyPaths);
    }

    /**
     * @param type
     * @param hasImages
     * @param hasText
     * @param feature
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#count(java.lang.Class, java.lang.Boolean, java.lang.Boolean, java.util.Set)
     */
    @Override
    public int count(Class<? extends DescriptionBase> type, Boolean hasImages, Boolean hasText, Set<Feature> feature) {
        return defaultService.count(type, hasImages, hasText, feature);
    }

    /**
     * @param clazz
     * @param queryString
     * @param matchmode
     * @param criteria
     * @param pageSize
     * @param pageNumber
     * @param orderHints
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IIdentifiableEntityService#findByTitle(java.lang.Class, java.lang.String, eu.etaxonomy.cdm.persistence.query.MatchMode, java.util.List, java.lang.Integer, java.lang.Integer, java.util.List, java.util.List)
     */
    @Override
    public Pager<DescriptionBase> findByTitle(Class<? extends DescriptionBase> clazz, String queryString, MatchMode matchmode, List<Criterion> criteria, Integer pageSize, Integer pageNumber, List<OrderHint> orderHints, List<String> propertyPaths) {
        return defaultService.findByTitle(clazz, queryString, matchmode, criteria, pageSize, pageNumber, orderHints, propertyPaths);
    }

    /**
     * @param type
     * @param limit
     * @param start
     * @param orderHints
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#list(java.lang.Class, java.lang.Integer, java.lang.Integer, java.util.List, java.util.List)
     */
    @Override
    public <S extends DescriptionBase> List<S> list(Class<S> type, Integer limit, Integer start, List<OrderHint> orderHints, List<String> propertyPaths) {
        return defaultService.list(type, limit, start, orderHints, propertyPaths);
    }

    /**
     * @param description
     * @param features
     * @param type
     * @param pageSize
     * @param pageNumber
     * @param propertyPaths
     * @return
     * @deprecated
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#getDescriptionElements(eu.etaxonomy.cdm.model.description.DescriptionBase, java.util.Set, java.lang.Class, java.lang.Integer, java.lang.Integer, java.util.List)
     */
    @Deprecated
    @Override
    public Pager<DescriptionElementBase> getDescriptionElements(DescriptionBase description, Set<Feature> features, Class<? extends DescriptionElementBase> type, Integer pageSize, Integer pageNumber, List<String> propertyPaths) {
        return defaultService.getDescriptionElements(description, features, type, pageSize, pageNumber, propertyPaths);
    }

    /**
     * @param configurator
     * @return
     * @see eu.etaxonomy.cdm.api.service.IIdentifiableEntityService#findByTitle(eu.etaxonomy.cdm.api.service.config.IIdentifiableEntityServiceConfigurator)
     */
    @Override
    public Pager<DescriptionBase> findByTitle(IIdentifiableEntityServiceConfigurator<DescriptionBase> configurator) {
        return defaultService.findByTitle(configurator);
    }

    /**
     * @param clazz
     * @param queryString
     * @param matchmode
     * @param criteria
     * @return
     * @see eu.etaxonomy.cdm.api.service.IIdentifiableEntityService#countByTitle(java.lang.Class, java.lang.String, eu.etaxonomy.cdm.persistence.query.MatchMode, java.util.List)
     */
    @Override
    public Integer countByTitle(Class<? extends DescriptionBase> clazz, String queryString, MatchMode matchmode, List<Criterion> criteria) {
        return defaultService.countByTitle(clazz, queryString, matchmode, criteria);
    }

    /**
     * @param uuid
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#load(java.util.UUID)
     */
    @Override
    public DescriptionBase load(UUID uuid) {
        return defaultService.load(uuid);
    }

    /**
     * @param uuid
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#load(java.util.UUID, java.util.List)
     */
    @Override
    public DescriptionBase load(UUID uuid, List<String> propertyPaths) {
        return defaultService.load(uuid, propertyPaths);
    }

    /**
     * @param configurator
     * @return
     * @see eu.etaxonomy.cdm.api.service.IIdentifiableEntityService#countByTitle(eu.etaxonomy.cdm.api.service.config.IIdentifiableEntityServiceConfigurator)
     */
    @Override
    public Integer countByTitle(IIdentifiableEntityServiceConfigurator<DescriptionBase> configurator) {
        return defaultService.countByTitle(configurator);
    }

    /**
     * @param transientObject
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#merge(eu.etaxonomy.cdm.model.common.ICdmBase)
     */
    @Override
    public DescriptionBase merge(DescriptionBase transientObject) {
        return defaultService.merge(transientObject);
    }

    /**
     * @param description
     * @param descriptionType
     * @param features
     * @param type
     * @param pageSize
     * @param pageNumber
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#pageDescriptionElements(eu.etaxonomy.cdm.model.description.DescriptionBase, java.lang.Class, java.util.Set, java.lang.Class, java.lang.Integer, java.lang.Integer, java.util.List)
     */
    @Override
    public Pager<DescriptionElementBase> pageDescriptionElements(DescriptionBase description, Class<? extends DescriptionBase> descriptionType, Set<Feature> features, Class<? extends DescriptionElementBase> type, Integer pageSize, Integer pageNumber, List<String> propertyPaths) {
        return defaultService.pageDescriptionElements(description, descriptionType, features, type, pageSize, pageNumber, propertyPaths);
    }

    /**
     * @param clazz
     * @param queryString
     * @param matchmode
     * @param criteria
     * @param pageSize
     * @param pageNumber
     * @param orderHints
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IIdentifiableEntityService#listByTitle(java.lang.Class, java.lang.String, eu.etaxonomy.cdm.persistence.query.MatchMode, java.util.List, java.lang.Integer, java.lang.Integer, java.util.List, java.util.List)
     */
    @Override
    public List<DescriptionBase> listByTitle(Class<? extends DescriptionBase> clazz, String queryString, MatchMode matchmode, List<Criterion> criteria, Integer pageSize, Integer pageNumber, List<OrderHint> orderHints, List<String> propertyPaths) {
        return defaultService.listByTitle(clazz, queryString, matchmode, criteria, pageSize, pageNumber, orderHints, propertyPaths);
    }

    /**
     * @param type
     * @param pageSize
     * @param pageNumber
     * @param orderHints
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#page(java.lang.Class, java.lang.Integer, java.lang.Integer, java.util.List, java.util.List)
     */
    @Override
    public <S extends DescriptionBase> Pager<S> page(Class<S> type, Integer pageSize, Integer pageNumber, List<OrderHint> orderHints, List<String> propertyPaths) {
        return defaultService.page(type, pageSize, pageNumber, orderHints, propertyPaths);
    }

    /**
     * @param persistentObject
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#refresh(eu.etaxonomy.cdm.model.common.ICdmBase)
     */
    @Override
    public UUID refresh(DescriptionBase persistentObject) {
        return defaultService.refresh(persistentObject);
    }

    /**
     * @param clazz
     * @param queryString
     * @param matchmode
     * @param criteria
     * @param pageSize
     * @param pageNumber
     * @param orderHints
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IIdentifiableEntityService#listByReferenceTitle(java.lang.Class, java.lang.String, eu.etaxonomy.cdm.persistence.query.MatchMode, java.util.List, java.lang.Integer, java.lang.Integer, java.util.List, java.util.List)
     */
    @Override
    public List<DescriptionBase> listByReferenceTitle(Class<? extends DescriptionBase> clazz, String queryString, MatchMode matchmode, List<Criterion> criteria, Integer pageSize, Integer pageNumber, List<OrderHint> orderHints, List<String> propertyPaths) {
        return defaultService.listByReferenceTitle(clazz, queryString, matchmode, criteria, pageSize, pageNumber, orderHints, propertyPaths);
    }

    /**
     * @param description
     * @param features
     * @param type
     * @param pageSize
     * @param pageNumber
     * @param propertyPaths
     * @return
     * @deprecated
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#listDescriptionElements(eu.etaxonomy.cdm.model.description.DescriptionBase, java.util.Set, java.lang.Class, java.lang.Integer, java.lang.Integer, java.util.List)
     */
    @Deprecated
    @Override
    public List<DescriptionElementBase> listDescriptionElements(DescriptionBase description, Set<Feature> features, Class<? extends DescriptionElementBase> type, Integer pageSize, Integer pageNumber, List<String> propertyPaths) {
        return defaultService.listDescriptionElements(description, features, type, pageSize, pageNumber, propertyPaths);
    }

    /**
     * @param tableName
     * @param limit
     * @param start
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#rows(java.lang.String, int, int)
     */
    @Override
    public List<DescriptionBase> rows(String tableName, int limit, int start) {
        return defaultService.rows(tableName, limit, start);
    }

    /**
     * @param newInstances
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#save(java.util.Collection)
     */
    @Override
    public Map<UUID, DescriptionBase> save(Collection<DescriptionBase> newInstances) {
        return null;
    }

    /**
     * @param newInstance
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#save(eu.etaxonomy.cdm.model.common.ICdmBase)
     */
    @Override
    public DescriptionBase save(DescriptionBase newInstance) {
        return null;
    }

    /**
     * @param transientObject
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#saveOrUpdate(eu.etaxonomy.cdm.model.common.ICdmBase)
     */
    @Override
    public UUID saveOrUpdate(DescriptionBase transientObject) {
        return null;
    }

    /**
     * @param clazz
     * @param queryString
     * @param pageSize
     * @param pageNumber
     * @param orderHints
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IIdentifiableEntityService#search(java.lang.Class, java.lang.String, java.lang.Integer, java.lang.Integer, java.util.List, java.util.List)
     */
    @Override
    public Pager<DescriptionBase> search(Class<? extends DescriptionBase> clazz, String queryString, Integer pageSize, Integer pageNumber, List<OrderHint> orderHints, List<String> propertyPaths) {
        return defaultService.search(clazz, queryString, pageSize, pageNumber, orderHints, propertyPaths);
    }

    /**
     * @param transientObjects
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#saveOrUpdate(java.util.Collection)
     */
    @Override
    public Map<UUID, DescriptionBase> saveOrUpdate(Collection<DescriptionBase> transientObjects) {
        return null;
    }

    /**
     * @param transientObject
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#update(eu.etaxonomy.cdm.model.common.ICdmBase)
     */
    @Override
    public UUID update(DescriptionBase transientObject) {
        return defaultService.update(transientObject);
    }

    /**
     * @param description
     * @param descriptionType
     * @param features
     * @param type
     * @param pageSize
     * @param pageNumber
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#listDescriptionElements(eu.etaxonomy.cdm.model.description.DescriptionBase, java.lang.Class, java.util.Set, java.lang.Class, java.lang.Integer, java.lang.Integer, java.util.List)
     */
    @Override
    public List<DescriptionElementBase> listDescriptionElements(DescriptionBase description, Class<? extends DescriptionBase> descriptionType, Set<Feature> features, Class<? extends DescriptionElementBase> type, Integer pageSize, Integer pageNumber, List<String> propertyPaths) {
        return defaultService.listDescriptionElements(description, descriptionType, features, type, pageSize, pageNumber, propertyPaths);
    }

    /**
     * @param example
     * @param includeProperties
     * @param limit
     * @param start
     * @param orderHints
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IService#list(eu.etaxonomy.cdm.model.common.ICdmBase, java.util.Set, java.lang.Integer, java.lang.Integer, java.util.List, java.util.List)
     */
    @Override
    public List<DescriptionBase> list(DescriptionBase example, Set<String> includeProperties, Integer limit, Integer start, List<OrderHint> orderHints, List<String> propertyPaths) {
        return defaultService.list(example, includeProperties, limit, start, orderHints, propertyPaths);
    }

    /**
     * @param clazz
     * @param matchStrategy
     * @param mergeStrategy
     * @return
     * @see eu.etaxonomy.cdm.api.service.IIdentifiableEntityService#deduplicate(java.lang.Class, eu.etaxonomy.cdm.strategy.match.IMatchStrategy, eu.etaxonomy.cdm.strategy.merge.IMergeStrategy)
     */
    @Override
    public int deduplicate(Class<? extends DescriptionBase> clazz, IMatchStrategy matchStrategy, IMergeStrategy mergeStrategy) {
        return defaultService.deduplicate(clazz, matchStrategy, mergeStrategy);
    }

    /**
     * @param annotatedObj
     * @param status
     * @param pageSize
     * @param pageNumber
     * @param orderHints
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#getDescriptionElementAnnotations(eu.etaxonomy.cdm.model.description.DescriptionElementBase, eu.etaxonomy.cdm.model.common.MarkerType, java.lang.Integer, java.lang.Integer, java.util.List, java.util.List)
     */
    @Override
    public Pager<Annotation> getDescriptionElementAnnotations(DescriptionElementBase annotatedObj, MarkerType status, Integer pageSize, Integer pageNumber, List<OrderHint> orderHints, List<String> propertyPaths) {
        return defaultService.getDescriptionElementAnnotations(annotatedObj, status, pageSize, pageNumber, orderHints, propertyPaths);
    }

    /**
     * @param clazz
     * @param queryString
     * @param pageSize
     * @param pageNumber
     * @param orderHints
     * @param matchMode
     * @return
     * @see eu.etaxonomy.cdm.api.service.IIdentifiableEntityService#findTitleCache(java.lang.Class, java.lang.String, java.lang.Integer, java.lang.Integer, java.util.List, eu.etaxonomy.cdm.persistence.query.MatchMode)
     */
    @Override
    public Pager<DescriptionBase> findTitleCache(Class<? extends DescriptionBase> clazz, String queryString, Integer pageSize, Integer pageNumber, List<OrderHint> orderHints, MatchMode matchMode) {
        return defaultService.findTitleCache(clazz, queryString, pageSize, pageNumber, orderHints, matchMode);
    }

    /**
     * @param taxon
     * @param scopes
     * @param geographicalScope
     * @param pageSize
     * @param pageNumber
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#pageTaxonDescriptions(eu.etaxonomy.cdm.model.taxon.Taxon, java.util.Set, java.util.Set, java.lang.Integer, java.lang.Integer, java.util.List)
     */
    @Override
    public Pager<TaxonDescription> pageTaxonDescriptions(Taxon taxon, Set<DefinedTerm> scopes, Set<NamedArea> geographicalScope, Integer pageSize, Integer pageNumber, List<String> propertyPaths) {
        return defaultService.pageTaxonDescriptions(taxon, scopes, geographicalScope, pageSize, pageNumber, propertyPaths);
    }

    /**
     * @param taxon
     * @param scopes
     * @param geographicalScope
     * @param markerTypes
     * @param pageSize
     * @param pageNumber
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#pageTaxonDescriptions(eu.etaxonomy.cdm.model.taxon.Taxon, java.util.Set, java.util.Set, java.util.Set, java.lang.Integer, java.lang.Integer, java.util.List)
     */
    @Override
    public Pager<TaxonDescription> pageTaxonDescriptions(Taxon taxon, Set<DefinedTerm> scopes, Set<NamedArea> geographicalScope, Set<MarkerType> markerTypes, Integer pageSize, Integer pageNumber, List<String> propertyPaths) {
        return defaultService.pageTaxonDescriptions(taxon, scopes, geographicalScope, markerTypes, pageSize, pageNumber, propertyPaths);
    }

    /**
     * @param taxon
     * @param scopes
     * @param geographicalScope
     * @param pageSize
     * @param pageNumber
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#listTaxonDescriptions(eu.etaxonomy.cdm.model.taxon.Taxon, java.util.Set, java.util.Set, java.lang.Integer, java.lang.Integer, java.util.List)
     */
    @Override
    public List<TaxonDescription> listTaxonDescriptions(Taxon taxon, Set<DefinedTerm> scopes, Set<NamedArea> geographicalScope, Integer pageSize, Integer pageNumber, List<String> propertyPaths) {
        return defaultService.listTaxonDescriptions(taxon, scopes, geographicalScope, pageSize, pageNumber, propertyPaths);
    }

    /**
     * @param taxon
     * @param scopes
     * @param geographicalScope
     * @param markerTypes
     * @param pageSize
     * @param pageNumber
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#listTaxonDescriptions(eu.etaxonomy.cdm.model.taxon.Taxon, java.util.Set, java.util.Set, java.util.Set, java.lang.Integer, java.lang.Integer, java.util.List)
     */
    @Override
    public List<TaxonDescription> listTaxonDescriptions(Taxon taxon, Set<DefinedTerm> scopes, Set<NamedArea> geographicalScope, Set<MarkerType> markerTypes, Integer pageSize, Integer pageNumber, List<String> propertyPaths) {
        return defaultService.listTaxonDescriptions(taxon, scopes, geographicalScope, markerTypes, pageSize, pageNumber, propertyPaths);
    }

    /**
     * @param taxonUuid
     * @param limitToGalleries
     * @param markerTypes
     * @param pageSize
     * @param pageNumber
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#listTaxonDescriptionMedia(java.util.UUID, boolean, java.util.Set, java.lang.Integer, java.lang.Integer, java.util.List)
     */
    @Override
    public List<Media> listTaxonDescriptionMedia(UUID taxonUuid, boolean limitToGalleries, Set<MarkerType> markerTypes, Integer pageSize, Integer pageNumber, List<String> propertyPaths) {
        return defaultService.listTaxonDescriptionMedia(taxonUuid, limitToGalleries, markerTypes, pageSize, pageNumber, propertyPaths);
    }

    /**
     * @param taxonUuid
     * @param limitToGalleries
     * @param markerTypes
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#countTaxonDescriptionMedia(java.util.UUID, boolean, java.util.Set)
     */
    @Override
    public int countTaxonDescriptionMedia(UUID taxonUuid, boolean limitToGalleries, Set<MarkerType> markerTypes) {
        return defaultService.countTaxonDescriptionMedia(taxonUuid, limitToGalleries, markerTypes);
    }

    /**
     * @param name
     * @param pageSize
     * @param pageNumber
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#getTaxonNameDescriptions(eu.etaxonomy.cdm.model.name.TaxonNameBase, java.lang.Integer, java.lang.Integer, java.util.List)
     */
    @Override
    public Pager<TaxonNameDescription> getTaxonNameDescriptions(TaxonNameBase name, Integer pageSize, Integer pageNumber, List<String> propertyPaths) {
        return defaultService.getTaxonNameDescriptions(name, pageSize, pageNumber, propertyPaths);
    }

    /**
     * @param namedAreas
     * @param presence
     * @param pageSize
     * @param pageNumber
     * @param orderHints
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#searchDescriptionByDistribution(java.util.Set, eu.etaxonomy.cdm.model.description.PresenceAbsenceTermBase, java.lang.Integer, java.lang.Integer, java.util.List, java.util.List)
     */
    @Override
    public Pager<TaxonDescription> searchDescriptionByDistribution(Set<NamedArea> namedAreas, PresenceAbsenceTerm presence, Integer pageSize, Integer pageNumber, List<OrderHint> orderHints, List<String> propertyPaths) {
        return defaultService.searchDescriptionByDistribution(namedAreas, presence, pageSize, pageNumber, orderHints, propertyPaths);
    }

    /**
     * @param clazz
     * @param queryString
     * @param pageSize
     * @param pageNumber
     * @param orderHints
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#searchElements(java.lang.Class, java.lang.String, java.lang.Integer, java.lang.Integer, java.util.List, java.util.List)
     */
    @Override
    public Pager<DescriptionElementBase> searchElements(Class<? extends DescriptionElementBase> clazz, String queryString, Integer pageSize, Integer pageNumber, List<OrderHint> orderHints, List<String> propertyPaths) {
        return defaultService.searchElements(clazz, queryString, pageSize, pageNumber, orderHints, propertyPaths);
    }

    /**
     * @param descriptionElement
     * @param pageSize
     * @param pageNumber
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#getMedia(eu.etaxonomy.cdm.model.description.DescriptionElementBase, java.lang.Integer, java.lang.Integer, java.util.List)
     */
    @Override
    public Pager<Media> getMedia(DescriptionElementBase descriptionElement, Integer pageSize, Integer pageNumber, List<String> propertyPaths) {
        return defaultService.getMedia(descriptionElement, pageSize, pageNumber, propertyPaths);
    }

    /**
     * @param taxon
     * @param features
     * @param type
     * @param pageSize
     * @param pageNumber
     * @param propertyPaths
     * @return
     * @deprecated
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#getDescriptionElementsForTaxon(eu.etaxonomy.cdm.model.taxon.Taxon, java.util.Set, java.lang.Class, java.lang.Integer, java.lang.Integer, java.util.List)
     */
    @Deprecated
    @Override
    public <T extends DescriptionElementBase> List<T> getDescriptionElementsForTaxon(Taxon taxon, Set<Feature> features, Class<T> type, Integer pageSize, Integer pageNumber, List<String> propertyPaths) {
        return defaultService.getDescriptionElementsForTaxon(taxon, features, type, pageSize, pageNumber, propertyPaths);
    }

    /**
     * @param taxon
     * @param features
     * @param type
     * @param pageSize
     * @param pageNumber
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#listDescriptionElementsForTaxon(eu.etaxonomy.cdm.model.taxon.Taxon, java.util.Set, java.lang.Class, java.lang.Integer, java.lang.Integer, java.util.List)
     */
    @Override
    public <T extends DescriptionElementBase> List<T> listDescriptionElementsForTaxon(Taxon taxon, Set<Feature> features, Class<T> type, Integer pageSize, Integer pageNumber, List<String> propertyPaths) {
        return defaultService.listDescriptionElementsForTaxon(taxon, features, type, pageSize, pageNumber, propertyPaths);
    }

    /**
     * @param taxon
     * @param features
     * @param type
     * @param pageSize
     * @param pageNumber
     * @param propertyPaths
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#pageDescriptionElementsForTaxon(eu.etaxonomy.cdm.model.taxon.Taxon, java.util.Set, java.lang.Class, java.lang.Integer, java.lang.Integer, java.util.List)
     */
    @Override
    public <T extends DescriptionElementBase> Pager<T> pageDescriptionElementsForTaxon(Taxon taxon, Set<Feature> features, Class<T> type, Integer pageSize, Integer pageNumber, List<String> propertyPaths) {
        return defaultService.pageDescriptionElementsForTaxon(taxon, features, type, pageSize, pageNumber, propertyPaths);
    }

    /**
     * @param featureTree
     * @param description
     * @param preferredLanguages
     * @param separator
     * @return
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#generateNaturalLanguageDescription(eu.etaxonomy.cdm.model.description.FeatureTree, eu.etaxonomy.cdm.model.description.TaxonDescription, java.util.List, java.lang.String)
     */
    @Override
    public String generateNaturalLanguageDescription(FeatureTree featureTree, TaxonDescription description, List<Language> preferredLanguages, String separator) {
        return defaultService.generateNaturalLanguageDescription(featureTree, description, preferredLanguages, separator);
    }

    /**
     * @param description
     * @return
     * @deprecated
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#hasStructuredData(eu.etaxonomy.cdm.model.description.DescriptionBase)
     */
    @Deprecated
    @Override
    public boolean hasStructuredData(DescriptionBase<?> description) {
        return defaultService.hasStructuredData(description);
    }

    /**
     * @param descriptionElements
     * @param targetDescription
     * @param isPaste
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#moveDescriptionElementsToDescription(java.util.Collection, eu.etaxonomy.cdm.model.description.DescriptionBase, boolean)
     */
    @Override
    public void moveDescriptionElementsToDescription(Collection<DescriptionElementBase> descriptionElements, DescriptionBase targetDescription, boolean isPaste) {
        defaultService.moveDescriptionElementsToDescription(descriptionElements, targetDescription, isPaste);
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#getOrderedDistributions(java.util.Set, boolean, boolean, java.util.Set, java.util.Set, java.util.List)
     */
    @Override
    public DistributionTree getOrderedDistributions(Set<TaxonDescription> taxonDescriptions, boolean subAreaPreference, boolean statusOrderPreference, Set<MarkerType> hideMarkedAreas, Set<NamedAreaLevel> omitLevels, List<String> propertyPaths) {
        return defaultService.getOrderedDistributions(taxonDescriptions, subAreaPreference, statusOrderPreference, hideMarkedAreas, omitLevels, propertyPaths);
    }

	@Override
	public DeleteResult isDeletable(DescriptionBase object,
			DeleteConfiguratorBase config) {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public DescriptionBase findWithoutFlush(UUID uuid) {
		return defaultService.findWithoutFlush(uuid);
	}

	@Override
	public <S extends DescriptionBase>  Pager<FindByIdentifierDTO<S>> findByIdentifier(Class<S> clazz, String identifier, DefinedTerm identifierType, MatchMode matchmode, boolean includeEntity, Integer pageSize, Integer pageNumber, List<String> propertyPaths){
		return defaultService.findByIdentifier(clazz, identifier, identifierType, matchmode, includeEntity, pageSize, pageNumber, propertyPaths);
	}

	@Override
	public DeleteResult deleteDescription(DescriptionBase description) {
		return defaultService.deleteDescription(description);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.cdm.api.service.IDescriptionService#pageNamedAreasInUse(boolean, java.lang.Integer, java.lang.Integer)
	 */
	@Override
	public Pager<TermDto> pageNamedAreasInUse(boolean includeAllParents, Integer pageSize, Integer pageNumber) {
	    return defaultService.pageNamedAreasInUse(includeAllParents, pageSize, pageNumber);
	}


    /* (non-Javadoc)
     * @see eu.etaxonomy.cdm.api.service.IService#delete(java.util.UUID)
     */
    @Override
    public DeleteResult delete(UUID uuid) {
        return defaultService.deleteDescription(uuid);
    }


    /* (non-Javadoc)
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#deleteDescription(java.util.UUID)
     */
    @Override
    public DeleteResult deleteDescription(UUID uuid) {
        return defaultService.delete(uuid);
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#deleteDescriptionElement(java.util.UUID)
     */
    @Override
    public UUID deleteDescriptionElement(UUID uuid) {
        return defaultService.deleteDescriptionElement(uuid);
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#moveTaxonDescriptions(eu.etaxonomy.cdm.model.taxon.Taxon, eu.etaxonomy.cdm.model.taxon.Taxon)
     */
    @Override
    public UpdateResult moveTaxonDescriptions(Taxon sourceTaxon, Taxon targetTaxon) {
        return defaultService.moveTaxonDescriptions(sourceTaxon, targetTaxon);
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.cdm.api.service.IDescriptionService#moveTaxonDescriptions(java.util.UUID, java.util.UUID)
     */
    @Override
    public UpdateResult moveTaxonDescriptions(UUID sourceTaxonUuid, UUID targetTaxonUuid) {
        return defaultService.moveTaxonDescriptions(sourceTaxonUuid, targetTaxonUuid);

    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.cdm.api.service.IService#delete(java.util.Collection)
     */
    @Override
    public DeleteResult delete(Collection<UUID> arg0) {
        return defaultService.delete(arg0);
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.cdm.api.service.IService#merge(java.util.List)
     */
    @Override
    public List<DescriptionBase> merge(List<DescriptionBase> arg0) {
        return defaultService.merge(arg0);
    }

}
