// $Id$
/**
* Copyright (C) 2014 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.editor.view.derivate;

import org.eclipse.core.runtime.Status;
import org.eclipse.jface.util.LocalSelectionTransfer;
import org.eclipse.jface.viewers.TreeNode;
import org.eclipse.jface.viewers.ViewerDropAdapter;
import org.eclipse.swt.dnd.DND;
import org.eclipse.swt.dnd.DropTargetEvent;
import org.eclipse.swt.dnd.TransferData;

import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.editor.view.derivate.operation.MoveDerivateOperation;
import eu.etaxonomy.taxeditor.model.AbstractUtility;
import eu.etaxonomy.taxeditor.model.MessagingUtils;

/**
 * @author pplitzner
 * @date 18.03.2014
 *
 */
public class DerivateDropListener extends ViewerDropAdapter {

    private final DerivateView derivateView;

    protected DerivateDropListener(DerivateView derivateView) {
        super(derivateView.getViewer());
        this.derivateView = derivateView;
    }

    /* (non-Javadoc)
     * @see org.eclipse.jface.viewers.ViewerDropAdapter#performDrop(java.lang.Object)
     */
    @Override
    public boolean performDrop(Object data) {
        if(derivateView.isDirty()){
            MessagingUtils.warningDialog("View has unsaved changes", this, "You need to save before performing this action");
            return false;
        }
        Object target = getCurrentTarget();
        if(target instanceof TreeNode && data instanceof DerivateViewSelection){
            DerivateViewSelection derivateViewSelection = (DerivateViewSelection)data;
            TreeNode targetNode = (TreeNode) target;
            TreeNode draggedNode = EditorUtil.getTreeNodeOfSelection(derivateViewSelection.getSelection());
            if(draggedNode!=null){
                MoveDerivateOperation moveDerivateOperation = new MoveDerivateOperation("Moving \""+derivateView.getLabelProvider().getDerivateText(draggedNode)+"\" to \""+derivateView.getLabelProvider().getDerivateText(targetNode)+"\"", EditorUtil.getUndoContext(), derivateView, draggedNode, targetNode);
                return AbstractUtility.executeOperation(moveDerivateOperation).equals(Status.OK_STATUS)?true:false;
            }
        }
        return false;
    }

    /* (non-Javadoc)
     * @see org.eclipse.jface.viewers.ViewerDropAdapter#validateDrop(java.lang.Object, int, org.eclipse.swt.dnd.TransferData)
     */
    @Override
    public boolean validateDrop(Object target, int operation, TransferData transferType) {
        return LocalSelectionTransfer.getTransfer().isSupportedType(transferType) && target instanceof TreeNode;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void dragOver(DropTargetEvent event) {
        super.dragOver(event);
        event.feedback = DND.FEEDBACK_SELECT | DND.FEEDBACK_SCROLL;
    }

}
