// $Id$
/**
* Copyright (C) 2014 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.editor.view.derivate.handler;

import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;
import java.util.UUID;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.handlers.HandlerUtil;

import eu.etaxonomy.cdm.api.service.IOccurrenceService;
import eu.etaxonomy.cdm.model.occurrence.SpecimenOrObservationBase;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonNode;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.editor.handler.OpenDerivateViewHandler;
import eu.etaxonomy.taxeditor.editor.view.derivate.DerivateViewEditorInput;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author pplitzner
 * @date Nov 25, 2014
 *
 */
public class OpenDerivateEditorForTaxonHandler extends AbstractHandler {

    /* (non-Javadoc)
     * @see org.eclipse.core.commands.IHandler#execute(org.eclipse.core.commands.ExecutionEvent)
     */
    @Override
    public Object execute(ExecutionEvent event) throws ExecutionException {
        ISelection currentSelection = HandlerUtil.getCurrentSelection(event);
        if(currentSelection instanceof IStructuredSelection){
            Iterator<?> selectionIterator = ((IStructuredSelection) currentSelection).iterator();
            Set<UUID> derivateUuids = new HashSet<UUID>();
            while(selectionIterator.hasNext()){
                Object object = selectionIterator.next();
                if(object instanceof TaxonNode){
                    TaxonNode node = (TaxonNode)object;
                    Taxon taxon = node.getTaxon();
                     List<SpecimenOrObservationBase> listByAssociatedTaxon = CdmStore.getService(IOccurrenceService.class).listByAssociatedTaxon(null, null, taxon, null, null, null, null, null);
                     for (SpecimenOrObservationBase specimenOrObservationBase : listByAssociatedTaxon) {
                         derivateUuids.add(specimenOrObservationBase.getUuid());
                    }
                }
            }
            if(derivateUuids.isEmpty()){
                MessagingUtils.warningDialog("Could not open Derivative Editor", this, "No Derivatives found");
                return null;
            }
            DerivateViewEditorInput input = new DerivateViewEditorInput(derivateUuids);
            try {
                EditorUtil.open(input);
            } catch (PartInitException e) {
                MessagingUtils.error(OpenDerivateViewHandler.class, "Could not open Derivative Editor", e);
            } catch (NullPointerException npe){
                MessagingUtils.messageDialog("Failed to open Editor", OpenDerivateViewHandler.class, "Could not open Derivative Editor. The derivative hierarchy is corrupted!", npe);
            }
        }
        return null;
    }

}
