/**
 * Copyright (C) 2011 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */
package eu.etaxonomy.taxeditor.editor.view.uses;

import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.dnd.Transfer;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Tree;

import eu.etaxonomy.cdm.model.common.CdmBase;
import eu.etaxonomy.taxeditor.editor.view.descriptive.DescriptionElementDragListener;
import eu.etaxonomy.taxeditor.editor.view.descriptive.DescriptionElementDropAdapter;
import eu.etaxonomy.taxeditor.editor.view.descriptive.DescriptionElementTransfer;
import eu.etaxonomy.taxeditor.editor.view.descriptive.DescriptiveViewPart;


/**
 * The Class create a specific Use View to keep the taxonomic view clean
 * @author a.theys
 * @created mar 13, 2012
 * @version 1.0
 */
public class UsesViewPart extends DescriptiveViewPart {

	public UsesViewPart() {
		super();
	}

	/** Constant <code>ID="eu.etaxonomy.taxeditor.editor.view.uses"</code> */
	public static final String ID = "eu.etaxonomy.taxeditor.editor.view.uses";
	/** {@inheritDoc} */
	@Override
	public void createViewer(Composite parent) {

		viewer = new TreeViewer(new Tree(parent, SWT.MULTI | SWT.H_SCROLL
				| SWT.V_SCROLL | SWT.FULL_SELECTION));
		viewer.setContentProvider(new UsesContentProvider(featureNodeContainerCache));
		viewer.setLabelProvider(new UsesLabelProvider());
		viewer.setAutoExpandLevel(2);



		Transfer[] transfers = new Transfer[] { DescriptionElementTransfer.getInstance() };
		viewer.addDragSupport(dndOperations, transfers, new DescriptionElementDragListener(
				this));
		viewer.addDropSupport(dndOperations, transfers,
				new DescriptionElementDropAdapter(viewer));

		// Propagate selection from viewer
		getSite().setSelectionProvider(viewer);

		showAllElementsAction = new ToggleDescriptionAction(false);
		hideAllElementsAction = new ToggleDescriptionAction(true);

		// Add context menu to tree
		createMenu();

		createToolbar();

	}

	@Override
    protected String getViewName(){
	    return "Uses";
	}

	/** {@inheritDoc} */
	@Override
	public boolean postOperation(CdmBase objectAffectedByOperation) {
		viewer.refresh();
		return super.postOperation(objectAffectedByOperation);
	}



}
